@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for workmailmessageflow service client
 
@@ -10,11 +11,11 @@ Usage::
     client: WorkMailMessageFlowClient = boto3.client("workmailmessageflow")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Any, Dict, TYPE_CHECKING, Type
-from botocore.exceptions import ClientError as Boto3ClientError
-from mypy_boto3_workmailmessageflow.type_defs import GetRawMessageContentResponseTypeDef
+from typing import Any, Dict, Type
 
+from botocore.exceptions import ClientError as Boto3ClientError
+
+from mypy_boto3_workmailmessageflow.type_defs import GetRawMessageContentResponseTypeDef
 
 __all__ = ("WorkMailMessageFlowClient",)
 
